@@ -39,14 +39,14 @@ class KSqueezedTextLabel;
 class QLabel;
 class QProgressBar;
 
-class KWidgetJobTracker::Private
+class Q_DECL_HIDDEN KWidgetJobTracker::Private
     : public KAbstractWidgetJobTracker::Private
 {
 public:
     Private(QWidget *parent, KWidgetJobTracker *tracker)
         : KAbstractWidgetJobTracker::Private(tracker)
         , parent(parent)
-        , eventLoopLocker(NULL)
+        , eventLoopLocker(nullptr)
     {
     }
 
@@ -55,10 +55,10 @@ public:
         delete eventLoopLocker;
     }
 
-    virtual void setStopOnClose(KJob *job, bool stopOnClose);
-    virtual bool stopOnClose(KJob *job) const;
-    virtual void setAutoDelete(KJob *job, bool autoDelete);
-    virtual bool autoDelete(KJob *job) const;
+    void setStopOnClose(KJob *job, bool stopOnClose) override;
+    bool stopOnClose(KJob *job) const override;
+    void setAutoDelete(KJob *job, bool autoDelete) override;
+    bool autoDelete(KJob *job) const override;
 
     void _k_showProgressWidget();
 
@@ -79,10 +79,10 @@ public:
     ProgressWidget(KJob *job, KWidgetJobTracker *object, QWidget *parent)
         : QWidget(parent), tracker(object), job(job), totalSize(0), totalFiles(0), totalDirs(0),
           processedSize(0), processedDirs(0), processedFiles(0), totalSizeKnown(false),
-          stopOnClose(true), jobRegistered(false), cancelClose(0), openFile(0),
-          openLocation(0), keepOpenCheck(0), pauseButton(0), sourceEdit(0),
-          destEdit(0), progressLabel(0), destInvite(0), speedLabel(0), sizeLabel(0),
-          resumeLabel(0), progressBar(0), suspendedProperty(false), refCount(1)
+          stopOnClose(true), jobRegistered(false), cancelClose(nullptr), openFile(nullptr),
+          openLocation(nullptr), keepOpenCheck(nullptr), pauseButton(nullptr), sourceEdit(nullptr),
+          destEdit(nullptr), progressLabel(nullptr), destInvite(nullptr), speedLabel(nullptr), sizeLabel(nullptr),
+          resumeLabel(nullptr), progressBar(nullptr), suspendedProperty(false), refCount(1)
     {
         if (!parent) {
             setWindowFlags(windowFlags() | Qt::Dialog);
@@ -94,7 +94,7 @@ public:
     ~ProgressWidget()
     {
         delete tracker->d->eventLoopLocker;
-        tracker->d->eventLoopLocker = NULL;
+        tracker->d->eventLoopLocker = nullptr;
     }
 
     KWidgetJobTracker *const tracker;
@@ -143,7 +143,7 @@ public:
     void deref();
     void closeNow();
 
-    virtual bool eventFilter(QObject *watched, QEvent *event);
+    bool eventFilter(QObject *watched, QEvent *event) override;
 
 public Q_SLOTS:
     virtual void infoMessage(const QString &plain, const QString &rich);
@@ -161,7 +161,7 @@ public Q_SLOTS:
     //TODO: Misses canResume()
 
 protected:
-    void closeEvent(QCloseEvent *event);
+    void closeEvent(QCloseEvent *event) override;
 
 private Q_SLOTS:
     void _k_keepOpenToggled(bool);
